#include "oled_switch_hw.h"
#include "paint_bitmap.h"

#define IMG_SIZE      6144      //For still images this size is good, because display is only this size.
#define BIG_IMG_SIZE  12288     //For scrolling, you must use bigger image, because of firmware on module,
                                //( Module attempts to scroll 96x64 display despite memory allocated being smaller )
//GPIOs
sbit OLED_SWITCH_RST         at GPIO_PIN1_bit;
sbit OLED_SWITCH_CS         at GPIO_PIN28_bit;
sbit OLED_SWITCH_CMD         at GPIO_PIN56_bit;

//Function Prototypes
void system_setup( buffer_size_t size );

void main()
{
    //Local Declarations
    scroll_t scroll;               //Used for scroll settings

    scroll.col_horiz_shift = 0x01; //Shift left to right
    scroll.row_offset      = 0;    //No offset of rows
    scroll.row_horiz_shift = 64;   //64: BIG IMAGE, 47:SMALL ( SMALL doesn't work well, because of firmware on module side )
    scroll.row_vert_shift  = 0;    //No vertical shifting
    scroll.interval        = 1;    //1: 10 frames between each shift

    //Setup
    system_setup( BIG ); //Provide size of allocated space for images ( 64x48 or 96x64 )

    oled_switch_deactivate_scrolling();                                   //Scrolling must be absolutely deactivated first
    oled_switch_scrolling_setup( scroll );                                //Next, setup scroll settings
    oled_switch_draw_565_img( oled_switch_logo_big_bmp, BIG_IMG_SIZE );   //Draw the image to scroll
    oled_switch_activate_scrolling();                                     //Activate scrolling on screen

    while( 1 )//Forever
    {

    }
}

void system_setup( buffer_size_t size )
{
    GPIO_Digital_Output( &GPIO_PORT_00_07, _GPIO_PINMASK_1 );   //RST
    GPIO_Digital_Output( &GPIO_PORT_24_31, _GPIO_PINMASK_4 );   //CS
    GPIO_Digital_Output( &GPIO_PORT_56_63, _GPIO_PINMASK_0 );   //CMD or CD  ( Command / Data )

    //UART
    UART1_Init( 115200 );
    Delay_ms(300);
    UART1_Write_Text( "UART Initialized\r\n" );

    //SPI
    SPIM1_Init_Advanced( _SPI_MASTER_CLK_RATIO_64, _SPI_CFG_PHASE_CAPTURE_RISING |
                     _SPI_CFG_POLARITY_IDLE_HIGH | _SPI_CFG_SS_AUTO_DISABLE |
                     _SPI_CFG_FIFO_DISABLE, _SPI_SS_LINE_NONE );
    Delay_ms(300);
    UART1_Write_Text( "SPI Initialized\r\n" );

    //Initialize OLED Switch click
    oled_switch_init( size );
    Delay_ms( 300 );
    UART1_Write_Text( "OLED Switch click Initialized\r\n" );

}